You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@flex.apache.org by jm...@apache.org on 2014/03/18 07:21:32 UTC

[1/3] git commit: [flex-flexunit] [refs/heads/release4.2.0] - fix up script to match Flexuint not Flex

Repository: flex-flexunit
Updated Branches:
  refs/heads/release4.2.0 a2e850699 -> fe2d22bc3


fix up script to match Flexuint not Flex


Project: http://git-wip-us.apache.org/repos/asf/flex-flexunit/repo
Commit: http://git-wip-us.apache.org/repos/asf/flex-flexunit/commit/a32c4fca
Tree: http://git-wip-us.apache.org/repos/asf/flex-flexunit/tree/a32c4fca
Diff: http://git-wip-us.apache.org/repos/asf/flex-flexunit/diff/a32c4fca

Branch: refs/heads/release4.2.0
Commit: a32c4fcadc345c49e163902822d886c892bcb846
Parents: a2e8506
Author: Justin Mclean <jm...@apache.org>
Authored: Mon Mar 17 09:07:36 2014 +1100
Committer: Justin Mclean <jm...@apache.org>
Committed: Mon Mar 17 09:07:36 2014 +1100

----------------------------------------------------------------------
 build/deploy_release_candidate.sh | 26 +++++++++-----------------
 1 file changed, 9 insertions(+), 17 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/flex-flexunit/blob/a32c4fca/build/deploy_release_candidate.sh
----------------------------------------------------------------------
diff --git a/build/make_release_branch.sh b/build/make_release_branch.sh
index bd4ebb9..7ae52fe 100755
--- a/build/make_release_branch.sh
+++ b/build/make_release_branch.sh
@@ -43,7 +43,7 @@ git push -u origin develop:release${FLEXUNIT_VERSION}
 cd ..
 mkdir "ApacheFlexUnit${FLEXUNIT_VERSION}"
 cd "ApacheFlexUnit${FLEXUNIT_VERSION}"
-git clone https://git-wip-us.apache.org/repos/asf/flex-sdk.git .
+git clone https://git-wip-us.apache.org/repos/asf/flex-flexunit .
 git checkout release${FLEXUNIT_VERSION}
 git tag -a apache-flexunit-${FLEXUNIT_VERSION}RC1 -m \'"Apache FlexUnit ${FLEXUNIT_VERSION} RC1"\'
-git push --tags
\ No newline at end of file
+git push --tags


[3/3] git commit: [flex-flexunit] [refs/heads/release4.2.0] - now working

Posted by jm...@apache.org.
now working


Project: http://git-wip-us.apache.org/repos/asf/flex-flexunit/repo
Commit: http://git-wip-us.apache.org/repos/asf/flex-flexunit/commit/fe2d22bc
Tree: http://git-wip-us.apache.org/repos/asf/flex-flexunit/tree/fe2d22bc
Diff: http://git-wip-us.apache.org/repos/asf/flex-flexunit/diff/fe2d22bc

Branch: refs/heads/release4.2.0
Commit: fe2d22bc3bf87cf53865abf9f77b5c77842cb592
Parents: c8680a9
Author: Justin Mclean <jm...@apache.org>
Authored: Mon Mar 17 09:17:04 2014 +1100
Committer: Justin Mclean <jm...@apache.org>
Committed: Mon Mar 17 09:17:04 2014 +1100

----------------------------------------------------------------------
 build/check_sigs.sh | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/flex-flexunit/blob/fe2d22bc/build/check_sigs.sh
----------------------------------------------------------------------
diff --git a/build/check_sigs.sh b/build/check_sigs.sh
index 96b22b2..0f92c02 100755
--- a/build/check_sigs.sh
+++ b/build/check_sigs.sh
@@ -34,7 +34,7 @@ then
 	exit 1
 fi
 
-FLEX_VERSION="$1"
+FLEX_VERSION="$2"
 CHECK=`echo "$FLEX_VERSION" | grep -q -E '[0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,3}$'`
 
 if [ $? -ne 0 ]
@@ -54,9 +54,9 @@ fi
 
 # Assumes FLEXUNIT_DEV_AREA has been set up and point to SVN checked out dev area
 
-VERSION_DIR="${FLEXUNIT_DEV_AREA}/sdk/${FLEXUNIT_VERSION}"
-RC_DIR="${FLEXUNIT_DEV_AREA}/sdk/${FLEXUNIT_VERSION}/rc${RELEASE_CANDIDATE}"
-BIN_DIR="${FLEXUNIT_DEV_AREA}/sdk/${FLEXUNIT_VERSION}/rc${RELEASE_CANDIDATE}/binaries"
+VERSION_DIR="${FLEXUNIT_DEV_AREA}/flexunit/${FLEXUNIT_VERSION}"
+RC_DIR="${FLEXUNIT_DEV_AREA}/flexunit/${FLEXUNIT_VERSION}/rc${RELEASE_CANDIDATE}"
+BIN_DIR="${FLEXUNIT_DEV_AREA}/flexunit/${FLEXUNIT_VERSION}/rc${RELEASE_CANDIDATE}/binaries"
 
 function checkFile() {
 	FILE="$1"
diff --git a/build/deploy_release_candidate.sh b/build/deploy_release_candidate.sh
index 204d35a..848f223 100755
--- a/build/deploy_release_candidate.sh
+++ b/build/deploy_release_candidate.sh
@@ -22,15 +22,15 @@
 
 if [ $# -ne 2 ]
 then
-    echo "Usage: deploy_release_candidate flex_version ([0-99].[0-99].[0-999]) release_candidate ([0-100])"
+    echo "Usage: deploy_release_candidate flexunit_version ([0-99].[0-99].[0-999]) release_candidate ([0-100])"
 fi
 
-FLEX_VERSION="$1"
-CHECK=`echo "$FLEX_VERSION" | grep -q -E '[0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,3}$'`
+FLEXUNIT_VERSION="$1"
+CHECK=`echo "$FLEXUNIT_VERSION" | grep -q -E '[0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,3}$'`
 
 if [ $? -ne 0 ]
 then
-	echo "Apache Flex version needs to be in the form [0-99].[0-99].[0-999]"
+	echo "Apache FlexUnit version needs to be in the form [0-99].[0-99].[0-999]"
 	exit 1;
 fi
 
@@ -39,16 +39,15 @@ CHECK=`echo "$RELEASE_CANDIDATE" | grep -q -E '[0-9]{1,2}'`
 
 if [ $? -ne 0 ]
 then
-	echo "Apache Flex release candidate to be in the range 1-99"
+	echo "Apache FlexUnit release candidate to be in the range 1-99"
 	exit 1;
 fi
 
 # Assumes FLEX_DEV_AREA has been set up and point to SVN checked out dev area
 
-VERSION_DIR="${FLEX_DEV_AREA}/sdk/${FLEX_VERSION}"
-RC_DIR="${FLEX_DEV_AREA}/sdk/${FLEX_VERSION}/rc${RELEASE_CANDIDATE}"
-BIN_DIR="${FLEX_DEV_AREA}/sdk/${FLEX_VERSION}/rc${RELEASE_CANDIDATE}/binaries"
-DOC_DIR="${FLEX_DEV_AREA}/sdk/${FLEX_VERSION}/rc${RELEASE_CANDIDATE}/docs"
+VERSION_DIR="${FLEXUNIT_DEV_AREA}/flexunit/${FLEXUNIT_VERSION}"
+RC_DIR="${FLEXUNIT_DEV_AREA}/flexunit/${FLEXUNIT_VERSION}/rc${RELEASE_CANDIDATE}"
+BIN_DIR="${FLEXUNIT_DEV_AREA}/flexunit/${FLEXUNIT_VERSION}/rc${RELEASE_CANDIDATE}/binaries"
 
 echo "RC directory is ${RC_DIR}"
 
@@ -67,17 +66,10 @@ then
 	mkdir "${BIN_DIR}"
 fi
 
-if [ ! -d "${DOC_DIR}" ]
-then
-	mkdir "${DOC_DIR}"
-fi
-
 cp README "${RC_DIR}"
 cp RELEASE_NOTES "${RC_DIR}"
 cp ./out/*-src.* "${RC_DIR}"
 cp ./out/*-bin.* "${BIN_DIR}"
-cp ./out/*-config.xml "${BIN_DIR}"
-cp ./out/*-asdocs.* "${DOC_DIR}"
 
 
 


[2/3] git commit: [flex-flexunit] [refs/heads/release4.2.0] - get code from right repo

Posted by jm...@apache.org.
get code from right repo


Project: http://git-wip-us.apache.org/repos/asf/flex-flexunit/repo
Commit: http://git-wip-us.apache.org/repos/asf/flex-flexunit/commit/c8680a98
Tree: http://git-wip-us.apache.org/repos/asf/flex-flexunit/tree/c8680a98
Diff: http://git-wip-us.apache.org/repos/asf/flex-flexunit/diff/c8680a98

Branch: refs/heads/release4.2.0
Commit: c8680a98f32f063a0d22bcdc3edfabf5645dd00d
Parents: a32c4fc
Author: Justin Mclean <jm...@apache.org>
Authored: Mon Mar 17 09:07:53 2014 +1100
Committer: Justin Mclean <jm...@apache.org>
Committed: Mon Mar 17 09:07:53 2014 +1100

----------------------------------------------------------------------
 build/make_release_branch.sh | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/flex-flexunit/blob/c8680a98/build/make_release_branch.sh
----------------------------------------------------------------------
@@ -39,16 +39,15 @@ CHECK=`echo "$RELEASE_CANDIDATE" | grep -q -E '[0-9]{1,2}'`
 fi
 
-# Assumes FLEX_DEV_AREA has been set up and point to SVN checked out dev area
+# Assumes FLEXUNIT_DEV_AREA has been set up and point to SVN checked out dev area
 